@@ -22,7 +22,11 @@ class TestCase(object):
         @app.route('/require/user', methods=['POST'])
         def require_user():
             params = get_request_params()
-            params.require('user')
-            return jsonify(params)
+            return jsonify(params.require('user'))
+
+        @app.route('/permit/user', methods=['POST'])
+        def permit_user():
+            params = get_request_params()
+            return jsonify(params.require('user').permit('name', 'age'))
 
         return app
